export default {
    "message": "Unexpected token foo",
    "column": 1,
    "index": 8,
    "lineNumber": 2
}